==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkReebGraphVolumeSkeletonFilter.java <==
// java wrapper for vtkReebGraphVolumeSkeletonFilter object
//

package vtk;
import vtk.*;

public class vtkReebGraphVolumeSkeletonFilter extends vtkDataObjectAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfSamples_2(int id0);
  public void SetNumberOfSamples(int id0)
    { SetNumberOfSamples_2(id0); }

  private native int GetNumberOfSamples_3();
  public int GetNumberOfSamples()
    { return GetNumberOfSamples_3(); }

  private native void SetNumberOfSmoothingIterations_4(int id0);
  public void SetNumberOfSmoothingIterations(int id0)
    { SetNumberOfSmoothingIterations_4(id0); }

  private native int GetNumberOfSmoothingIterations_5();
  public int GetNumberOfSmoothingIterations()
    { return GetNumberOfSmoothingIterations_5(); }

  private native void SetFieldId_6(int id0);
  public void SetFieldId(int id0)
    { SetFieldId_6(id0); }

  private native int GetFieldId_7();
  public int GetFieldId()
    { return GetFieldId_7(); }

  private native long GetOutput_8();
  public vtkTable GetOutput() {
    long temp = GetOutput_8();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkReebGraphVolumeSkeletonFilter() { super(); }

  public vtkReebGraphVolumeSkeletonFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-2-aarch64.pkg.tar.xz: vtk/vtkReebGraphVolumeSkeletonFilter.java <==
// java wrapper for vtkReebGraphVolumeSkeletonFilter object
//

package vtk;
import vtk.*;

public class vtkReebGraphVolumeSkeletonFilter extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfSamples_2(int id0);
  public void SetNumberOfSamples(int id0)
    { SetNumberOfSamples_2(id0); }

  private native int GetNumberOfSamples_3();
  public int GetNumberOfSamples()
    { return GetNumberOfSamples_3(); }

  private native void SetNumberOfSmoothingIterations_4(int id0);
  public void SetNumberOfSmoothingIterations(int id0)
    { SetNumberOfSmoothingIterations_4(id0); }

  private native int GetNumberOfSmoothingIterations_5();
  public int GetNumberOfSmoothingIterations()
    { return GetNumberOfSmoothingIterations_5(); }

  private native void SetFieldId_6(int id0);
  public void SetFieldId(int id0)
    { SetFieldId_6(id0); }

  private native int GetFieldId_7();
  public int GetFieldId()
    { return GetFieldId_7(); }

  private native long GetOutput_8();
  public vtkTable GetOutput() {
    long temp = GetOutput_8();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkReebGraphVolumeSkeletonFilter() { super(); }

  public vtkReebGraphVolumeSkeletonFilter(long id) { super(id); }
  public native long   VTKInit();

}
